@@ -6,7 +6,7 @@ Implements the CLI entry point:
 - Rich console terminal output
 - ASCII logo rendering
 - --version and --help options
-- Five core commands: init, doctor, status, backup, update
+- Five core commands: init, doctor, status, update
 """
 
 import sys
@@ -16,12 +16,11 @@ import pyfiglet
 from rich.console import Console
 
 from moai_adk import __version__
-from moai_adk.cli.commands.backup import backup
 from moai_adk.cli.commands.doctor import doctor
 from moai_adk.cli.commands.init import init
-from moai_adk.cli.commands.migrate import migrate
 from moai_adk.cli.commands.status import status
 from moai_adk.cli.commands.update import update
+from moai_adk.statusline.main import build_statusline_data
 
 console = Console()
 
@@ -62,86 +61,33 @@ def cli(ctx: click.Context) -> None:
 cli.add_command(init)
 cli.add_command(doctor)
 cli.add_command(status)
-cli.add_command(backup)
-cli.add_command(migrate)
 cli.add_command(update)
 
 
-# 링크 검증 명령
-@click.command(name="validate-links")
-@click.option(
-    "--file",
-    "-f",
-    default="README.ko.md",
-    help="검증할 파일 경로 (기본값: README.ko.md)",
-)
-@click.option(
-    "--max-concurrent",
-    "-c",
-    type=int,
-    default=3,
-    help="동시에 검증할 최대 링크 수 (기본값: 3)",
-)
-@click.option(
-    "--timeout", "-t", type=int, default=8, help="요청 타임아웃 (초) (기본값: 8)"
-)
-@click.option("--output", "-o", help="결과를 저장할 파일 경로")
-@click.option("--verbose", "-v", is_flag=True, help="상세한 진행 상황 표시")
-def validate_links(file, max_concurrent, timeout, output, verbose):
-    """온라인 문서 링크 검증"""
-    from moai_adk.cli.commands.validate_links import run_command as validate_links_run
+# statusline command (for Claude Code statusline rendering)
+@click.command(name="statusline")
+def statusline() -> None:
+    """Render Claude Code statusline (internal use only)"""
+    import json
+    import sys
 
-    # CLI 명령 실행
-    sys.exit(validate_links_run(locals()))
+    try:
+        # Read JSON context from stdin
+        input_data = sys.stdin.read() if not sys.stdin.isatty() else "{}"
+        context = json.loads(input_data) if input_data else {}
+    except (json.JSONDecodeError, EOFError, ValueError):
+        context = {}
+
+    # Render statusline
+    output = build_statusline_data(context, mode="extended")
+    print(output, end="")
+
+
+cli.add_command(statusline)
 
 
-# 사용자 경험 개선 명령
-@click.command(name="improve-ux")
-@click.option(
-    "--url",
-    "-u",
-    default="https://adk.mo.ai.kr",
-    help="분석할 URL (기본값: https://adk.mo.ai.kr)",
-)
-@click.option("--output", "-o", help="분석 결과를 저장할 파일 경로")
-@click.option(
-    "--format",
-    "-f",
-    type=click.Choice(["json", "markdown", "text"]),
-    default="markdown",
-    help="출력 형식 (기본값: markdown)",
-)
-@click.option("--verbose", "-v", is_flag=True, help="상세한 진행 상황 표시")
-@click.option(
-    "--max-workers",
-    "-w",
-    type=int,
-    default=5,
-    help="동시에 처리할 최대 작업 수 (기본값: 5)",
-)
-def improve_ux(url, output, format, verbose, max_workers):
-    """사용자 경험 개선 분석"""
-
-    # 임시 args 객체 생성
-    class Args:
-        def __init__(self, **kwargs):
-            for key, value in kwargs.items():
-                setattr(self, key, value)
-
-    args = Args(
-        url=url, output=output, format=format, verbose=verbose, max_workers=max_workers
-    )
-
-    # CLI 명령 실행
-    from moai_adk.cli.commands.improve_user_experience import (
-        run_command as improve_ux_run,
-    )
-
-    sys.exit(improve_ux_run(args))
 
 
-cli.add_command(validate_links)
-cli.add_command(improve_ux)
 
 
 def main() -> int:
