@@ -20,7 +20,6 @@ class ProjectSetupAnswers(TypedDict):
     locale: str  # ko | en | ja | zh | other (default from init)
     language: str | None  # Will be set in /alfred:0-project
     author: str  # Will be set in /alfred:0-project
-    mcp_servers: list[str]  # Selected MCP servers to install
     custom_language: str | None  # User input for "other" language option
 
 
@@ -50,7 +49,6 @@ def prompt_project_setup(
         "locale": "en",  # Default: will be configurable in /alfred:0-project
         "language": None,  # Will be detected in /alfred:0-project
         "author": "",  # Will be set in /alfred:0-project
-        "mcp_servers": [],  # Selected MCP servers
         "custom_language": None,  # User input for other language
     }
 
@@ -89,10 +87,10 @@ def prompt_project_setup(
 
         # Build choices list
         language_choices = [
-            "한국어 (Korean)",
+            "Korean (한국어)",
             "English",
-            "日本語 (Japanese)",
-            "中文 (Chinese)",
+            "Japanese (日本語)",
+            "Chinese (中文)",
             "Other - Manual input",
         ]
 
@@ -109,10 +107,10 @@ def prompt_project_setup(
 
         # Map choice name back to value
         choice_mapping = {
-            "한국어 (Korean)": "ko",
+            "Korean (한국어)": "ko",
             "English": "en",
-            "日本語 (Japanese)": "ja",
-            "中文 (Chinese)": "zh",
+            "Japanese (日本語)": "ja",
+            "Chinese (中文)": "zh",
             "Other - Manual input": "other",
         }
         language_choice = choice_mapping.get(language_choice_name)
@@ -136,26 +134,15 @@ def prompt_project_setup(
         else:
             answers["locale"] = language_choice
             language_names = {
-                "ko": "한국어 (Korean)",
+                "ko": "Korean (한국어)",
                 "en": "English",
-                "ja": "日本語 (Japanese)",
-                "zh": "中文 (Chinese)",
+                "ja": "Japanese (日本語)",
+                "zh": "Chinese (中文)",
             }
             console.print(
                 f"[cyan]🌐 Selected Language:[/cyan] {language_names.get(language_choice, language_choice)}"
             )
 
-        # Auto-install MCP servers
-        mcp_servers = ["context7", "playwright", "sequential-thinking"]
-        answers["mcp_servers"] = mcp_servers
-        console.print("\n[blue]🔧 MCP (Model Context Protocol) Configuration[/blue]")
-        console.print(
-            "[dim]Enhance AI capabilities with MCP servers (auto-installing recommended servers)[/dim]\n"
-        )
-        console.print(
-            f"[green]✅ MCP servers auto-installed: {', '.join(mcp_servers)}[/green]"
-        )
-
         return answers
 
     except KeyboardInterrupt:
