@@ -8,6 +8,7 @@ Provides comprehensive language validation capabilities for programming language
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Set, Tuple
 
+
 # Language detector functionality removed due to missing dependency
 # Using simplified language detection for now
 def get_all_supported_languages():
@@ -16,7 +17,6 @@ def get_all_supported_languages():
 
 def get_language_by_file_extension(extension: str) -> Optional[str]:
     """Get programming language by file extension."""
-    from pathlib import Path
 
     # Handle Path objects and strings
     if hasattr(extension, 'suffix'):
@@ -127,8 +127,8 @@ class LanguageValidator:
             self.supported_languages = set(lang.lower() for lang in supported_languages)
 
         # Compile regex patterns for efficient matching
-        self._directory_patterns = {}
-        self._exclude_patterns_cache = {}
+        self._directory_patterns: Dict[str, Any] = {}
+        self._exclude_patterns_cache: Dict[str, Any] = {}
 
         # Initialize analysis cache for statistics tracking
         self._analysis_cache = {
@@ -324,7 +324,7 @@ class LanguageValidator:
             return config_patterns[filename]
 
         # Extract extension and try normal detection
-        extension = Path(filename).suffix.lower()
+        Path(filename).suffix.lower()
         return self.detect_language_from_extension(filename)
 
     def validate_file_extension(self, file_path: Any, language: str) -> bool:
@@ -461,7 +461,7 @@ class LanguageValidator:
         expected_dirs = self.get_expected_directories(language)
 
         # Group files by directory
-        files_by_dir = {}
+        files_by_dir: Dict[str, List[str]] = {}
         for file_path, is_source in project_files.items():
             if is_source:  # Only validate source files
                 dir_path = str(Path(file_path).parent) + "/"
@@ -483,13 +483,11 @@ class LanguageValidator:
                 )
 
         # Check for files in unexpected directories
-        config = {}  # Using empty config for default exclude patterns
-        exclude_patterns = get_exclude_patterns(config)
-
+        # Note: Using simplified check since is_code_directory signature changed
         for file_path, is_source in project_files.items():
             if is_source:
-                path_obj = Path(file_path)
-                if not is_code_directory(path_obj, config, language):
+                path_str = str(file_path)
+                if not is_code_directory(path_str):
                     issues.append(f"Source file in unexpected location: {file_path}")
 
         return len(issues) == 0, issues
@@ -511,7 +509,7 @@ class LanguageValidator:
         else:
             validated_files = files
 
-        stats = {}
+        stats: Dict[str, int] = {}
         total_files = 0
         detected_extensions = set()
 
