@@ -103,11 +103,18 @@ class MCPSetupManager:
             console.print(f"❌ Failed to copy MCP configuration: {e}")
             return False
 
-    def setup_mcp_servers(self, selected_servers: list[str]) -> bool:
-        """Complete MCP server setup process with platform adaptation"""
-        if not selected_servers:
-            console.print("ℹ️  No MCP servers selected")
-            return True
+    def setup_mcp_servers(self, selected_servers: list[str] | None = None) -> bool:
+        """Copy MCP server template to project
 
-        console.print("🔧 Setting up MCP servers...")
+        This method copies ALL MCP servers from the package template to .mcp.json.
+        Server selection happens in settings.local.json via enabledMcpjsonServers array.
+
+        Args:
+            selected_servers: Deprecated parameter (ignored, kept for backward compatibility)
+
+        Returns:
+            True if setup successful, False otherwise
+        """
+        # This method now only copies the full template
+        # User selection is done via settings.local.json
         return self.copy_template_mcp_config()
