@@ -12,6 +12,7 @@ Enhanced with:
 
 from __future__ import annotations
 
+import json
 import logging
 import re
 import shutil
@@ -104,7 +105,6 @@ class TemplateProcessor:
     # Common template variables with validation hints
     COMMON_TEMPLATE_VARIABLES = {
         "PROJECT_DIR": "Cross-platform project path (run /alfred:0-project to set)",
-        "HOOK_PROJECT_DIR": "Cross-platform hook path (deprecated, use PROJECT_DIR instead)",
         "PROJECT_NAME": "Project name (run /alfred:0-project to set)",
         "AUTHOR": "Project author (run /alfred:0-project to set)",
         "CONVERSATION_LANGUAGE": "Interface language (run /alfred:0-project to set)",
@@ -466,14 +466,6 @@ class TemplateProcessor:
         package_root = current_file.parent.parent.parent
         return package_root / "templates"
 
-    def set_context(self, context: dict[str, str]) -> None:
-        """Set variable substitution context.
-
-        Args:
-            context: Dictionary of template variables.
-        """
-        self.context = context
-
     def _substitute_variables(self, content: str) -> tuple[str, list[str]]:
         """
         Substitute template variables in content with enhanced validation and caching.
@@ -789,6 +781,7 @@ class TemplateProcessor:
         self._copy_github(silent)
         self._copy_claude_md(silent)
         self._copy_gitignore(silent)
+        self._copy_mcp_json(silent)
 
         if not silent:
             console.print("✅ Templates copied successfully")
@@ -857,16 +850,20 @@ class TemplateProcessor:
         # Create .claude directory if not exists
         dst.mkdir(parents=True, exist_ok=True)
 
-        # Alfred folders to copy wholesale (overwrite)
-        alfred_folders = [
+        # Alfred and Moai folders to copy wholesale (overwrite)
+        # Including both legacy alfred/ and new moai/ structure
+        alfred_moai_folders = [
             "hooks/alfred",
+            "hooks/moai",
             "commands/alfred",  # Contains 0-project.md, 1-plan.md, 2-run.md, 3-sync.md
-            "output-styles/alfred",
+            "commands/moai",
+            "output-styles/moai",
             "agents/alfred",
+            "agents/moai",
         ]
 
-        # 1. Copy Alfred folders wholesale (backup before delete & overwrite)
-        for folder in alfred_folders:
+        # 1. Copy Alfred and Moai folders wholesale (backup before delete & overwrite)
+        for folder in alfred_moai_folders:
             src_folder = src / folder
             dst_folder = dst / folder
 
@@ -881,6 +878,34 @@ class TemplateProcessor:
                 if not silent:
                     console.print(f"   ✅ .claude/{folder}/ overwritten")
 
+        # 1.5 Copy other subdirectories in parent folders (e.g., output-styles/moai, hooks/shared)
+        # This ensures non-alfred subdirectories are also copied
+        parent_folders_with_subdirs = ["output-styles", "hooks", "commands", "agents"]
+        for parent_name in parent_folders_with_subdirs:
+            src_parent = src / parent_name
+            if not src_parent.exists():
+                continue
+
+            for subdir in src_parent.iterdir():
+                if not subdir.is_dir():
+                    continue
+
+                # Skip alfred subdirectories (already handled above)
+                if subdir.name == "alfred":
+                    continue
+
+                rel_subdir = f"{parent_name}/{subdir.name}"
+                dst_subdir = dst / parent_name / subdir.name
+
+                if dst_subdir.exists():
+                    # For non-alfred directories, overwrite with merge if necessary
+                    shutil.rmtree(dst_subdir)
+
+                # Copy the subdirectory
+                shutil.copytree(subdir, dst_subdir)
+                if not silent:
+                    console.print(f"   ✅ .claude/{rel_subdir}/ copied")
+
         # 2. Copy other files/folders individually (smart merge for settings.json)
         all_warnings = []
         for item in src.iterdir():
@@ -1091,6 +1116,47 @@ class TemplateProcessor:
         """
         self.merger.merge_gitignore(src, dst)
 
+    def _copy_mcp_json(self, silent: bool = False) -> None:
+        """.mcp.json copy (smart merge with existing MCP server configuration)."""
+        src = self.template_root / ".mcp.json"
+        dst = self.target_path / ".mcp.json"
+
+        if not src.exists():
+            return
+
+        # Merge with existing .mcp.json when present (preserve user-added MCP servers)
+        if dst.exists():
+            self._merge_mcp_json(src, dst)
+            if not silent:
+                console.print("   🔄 .mcp.json merged (user MCP servers preserved)")
+        else:
+            shutil.copy2(src, dst)
+            if not silent:
+                console.print("   ✅ .mcp.json copy complete")
+
+    def _merge_mcp_json(self, src: Path, dst: Path) -> None:
+        """Smart merge for .mcp.json (preserve user-added MCP servers).
+
+        Args:
+            src: Template .mcp.json.
+            dst: Project .mcp.json.
+        """
+        try:
+            src_data = json.loads(src.read_text(encoding="utf-8"))
+            dst_data = json.loads(dst.read_text(encoding="utf-8"))
+
+            # Merge mcpServers: preserve user servers, update template servers
+            if "mcpServers" in src_data:
+                if "mcpServers" not in dst_data:
+                    dst_data["mcpServers"] = {}
+                # Update with template servers (preserves existing user servers)
+                dst_data["mcpServers"].update(src_data["mcpServers"])
+
+            # Write merged result back
+            dst.write_text(json.dumps(dst_data, indent=2, ensure_ascii=False), encoding="utf-8")
+        except json.JSONDecodeError as e:
+            console.print(f"[yellow]⚠️ Failed to merge .mcp.json: {e}[/yellow]")
+
     def merge_config(self, detected_language: str | None = None) -> dict[str, str]:
         """Delegate the smart merge for config.json.
 
