@@ -23,6 +23,8 @@ class StatuslineData:
     duration: str
     directory: str
     active_task: str
+    claude_version: str = ""  # Claude Code version (e.g., "2.0.46")
+    output_style: str = ""  # Output style name (e.g., "R2-D2", "Yoda")
     update_available: bool = False
     latest_version: str = ""
 
@@ -86,7 +88,7 @@ class StatuslineRenderer:
     def _build_compact_parts(self, data: StatuslineData) -> List[str]:
         """
         Build parts list for compact mode with labeled sections
-        Format: 🤖 Model | 🗿 Version | Output Style | 📋 TODO | 🔀 Git: Branch | Changes
+        New Format: 🤖 Model | 🔅 Claude Code Version | 🗿 MoAI Version | 💬 Style | 📊 Changes | 🔀 Branch
 
         Args:
             data: StatuslineData instance
@@ -100,9 +102,20 @@ class StatuslineRenderer:
         if self._display_config.model:
             parts.append(f"🤖 {data.model}")
 
-        # Add version if display enabled (system status)
+        # Add Claude Code version if available
+        if data.claude_version:
+            claude_ver_str = data.claude_version if data.claude_version.startswith("v") else f"v{data.claude_version}"
+            parts.append(f"🔅 {claude_ver_str}")
+
+        # Add MoAI version if display enabled (system status)
         if self._display_config.version:
-            parts.append(f"🗿 Ver {data.version}")
+            # Add 'v' prefix if not already present
+            version_str = data.version if data.version.startswith("v") else f"v{data.version}"
+            parts.append(f"🗿 {version_str}")
+
+        # Add output style if not empty
+        if data.output_style:
+            parts.append(f"💬 {data.output_style}")
 
         # Add git status if display enabled and status not empty
         if self._display_config.git_status and data.git_status:
@@ -121,7 +134,7 @@ class StatuslineRenderer:
     def _fit_to_constraint(self, data: StatuslineData, max_length: int) -> str:
         """
         Fit statusline to character constraint by truncating
-        Format: 🤖 Model | 🗿 Version | Output Style | 📋 TODO | 🔀 Git: Branch | Changes
+        New Format: 🤖 Model | 🔅 Claude Code Version | 🗿 MoAI Version | 💬 Style | 📊 Changes | 🔀 Branch
 
         Args:
             data: StatuslineData instance
@@ -131,11 +144,21 @@ class StatuslineRenderer:
             Truncated statusline string
         """
         # Try with truncated branch first
-        truncated_branch = self._truncate_branch(data.branch, max_length=20)
-        parts = [
-            f"🤖 {data.model}",
-            f"🗿 Ver {data.version}",
-        ]
+        truncated_branch = self._truncate_branch(data.branch, max_length=30)
+        version_str = data.version if data.version.startswith("v") else f"v{data.version}"
+
+        parts = [f"🤖 {data.model}"]
+
+        # Add Claude Code version if available
+        if data.claude_version:
+            claude_ver_str = data.claude_version if data.claude_version.startswith("v") else f"v{data.claude_version}"
+            parts.append(f"🔅 {claude_ver_str}")
+
+        parts.append(f"🗿 {version_str}")
+
+        # Add output style if not empty
+        if data.output_style:
+            parts.append(f"💬 {data.output_style}")
 
         # Add git status if display enabled and status not empty
         if self._display_config.git_status and data.git_status:
@@ -153,23 +176,37 @@ class StatuslineRenderer:
         # If still too long, try more aggressive branch truncation
         if len(result) > max_length:
             truncated_branch = self._truncate_branch(data.branch, max_length=12)
-            parts = [
-                f"🤖 {data.model}",
-                f"🗿 Ver {data.version}",
-            ]
+            parts = [f"🤖 {data.model}"]
+
+            if data.claude_version:
+                claude_ver_str = (
+                    data.claude_version if data.claude_version.startswith("v") else f"v{data.claude_version}"
+                )
+                parts.append(f"🔅 {claude_ver_str}")
+
+            parts.append(f"🗿 {version_str}")
+
             if data.git_status:
                 parts.append(f"📊 {data.git_status}")
+            if data.output_style:
+                parts.append(f"💬 {data.output_style}")
             parts.append(f"🔀 {truncated_branch}")
             if data.active_task.strip():
                 parts.append(data.active_task)
             result = self._format_config.separator.join(parts)
 
-        # If still too long, remove active_task
-        if len(result) > max_length and data.active_task.strip():
-            parts = [
-                f"🤖 {data.model}",
-                f"🗿 Ver {data.version}",
-            ]
+        # If still too long, remove output_style and active_task
+        if len(result) > max_length:
+            parts = [f"🤖 {data.model}"]
+
+            if data.claude_version:
+                claude_ver_str = (
+                    data.claude_version if data.claude_version.startswith("v") else f"v{data.claude_version}"
+                )
+                parts.append(f"🔅 {claude_ver_str}")
+
+            parts.append(f"🗿 {version_str}")
+
             if data.git_status:
                 parts.append(f"📊 {data.git_status}")
             parts.append(f"🔀 {truncated_branch}")
@@ -185,7 +222,7 @@ class StatuslineRenderer:
         """
         Render extended mode: Full path and detailed info with labels
         Constraint: <= 120 characters
-        Format: 🤖 Model | 🗿 Version | Output Style | 📋 TODO | 🔀 Git: Branch | Changes
+        New Format: 🤖 Model | 🔅 Claude Code Version | 🗿 MoAI Version | 💬 Style | 📊 Changes | 🔀 Branch
 
         Args:
             data: StatuslineData instance
@@ -194,6 +231,7 @@ class StatuslineRenderer:
             Formatted statusline string (max 120 chars)
         """
         branch = self._truncate_branch(data.branch, max_length=30)
+        version_str = data.version if data.version.startswith("v") else f"v{data.version}"
 
         parts = []
 
@@ -201,9 +239,18 @@ class StatuslineRenderer:
         if self._display_config.model:
             parts.append(f"🤖 {data.model}")
 
-        # Add version if display enabled
+        # Add Claude Code version if available
+        if data.claude_version:
+            claude_ver_str = data.claude_version if data.claude_version.startswith("v") else f"v{data.claude_version}"
+            parts.append(f"🔅 {claude_ver_str}")
+
+        # Add MoAI version if display enabled
         if self._display_config.version:
-            parts.append(f"🗿 Ver {data.version}")
+            parts.append(f"🗿 {version_str}")
+
+        # Add output style if not empty
+        if data.output_style:
+            parts.append(f"💬 {data.output_style}")
 
         # Add git status if display enabled and status not empty
         if self._display_config.git_status and data.git_status:
@@ -221,26 +268,27 @@ class StatuslineRenderer:
 
         # If exceeds limit, try truncating branch
         if len(result) > 120:
-            branch = self._truncate_branch(data.branch, max_length=20)
-            parts = [
-                f"🤖 {data.model}",
-                f"🗿 Ver {data.version}",
-            ]
+            branch = self._truncate_branch(data.branch, max_length=30)
+            parts = [f"🤖 {data.model}"]
 
-            # Add optional parts only if they have content
-            if self._display_config.output_style and data.output_style.strip():
-                # Use Yoda-specific emoji for Yoda styles only
-                if "yoda" in data.output_style.lower() or "Yoda Master" in data.output_style:
-                    parts.append(f"🧙 {data.output_style}")
-                else:
-                    parts.append(f"{data.output_style}")
-            if self._display_config.todo_count and data.todo_count.strip():
-                parts.append(f"📋 {data.todo_count}")
+            if data.claude_version:
+                claude_ver_str = (
+                    data.claude_version if data.claude_version.startswith("v") else f"v{data.claude_version}"
+                )
+                parts.append(f"🔅 {claude_ver_str}")
+
+            parts.append(f"🗿 {version_str}")
+
+            # Add git status if display enabled and not empty
+            if self._display_config.git_status and data.git_status:
+                parts.append(f"📊 {data.git_status}")
+
+            # Add output style if not empty
+            if data.output_style:
+                parts.append(f"💬 {data.output_style}")
 
             parts.append(f"🔀 {branch}")
 
-            if data.git_status:
-                parts.append(f"Changes: {data.git_status}")
             if data.active_task.strip():
                 parts.append(data.active_task)
             result = self._format_config.separator.join(parts)
@@ -251,7 +299,7 @@ class StatuslineRenderer:
         """
         Render minimal mode: Extreme space constraint with minimal labels
         Constraint: <= 40 characters
-        Format: 🤖 Model | 🗿 Ver Version | Changes: +staged M modified ? untracked
+        New Format: 🤖 Model | 🔅 Claude Code Ver | 🗿 MoAI Ver | Changes
 
         Args:
             data: StatuslineData instance
@@ -265,9 +313,20 @@ class StatuslineRenderer:
         if self._display_config.model:
             parts.append(f"🤖 {data.model}")
 
-        # Add version if display enabled
+        # Add Claude Code version if available (truncated for minimal)
+        if data.claude_version:
+            claude_ver_str = data.claude_version if data.claude_version.startswith("v") else f"v{data.claude_version}"
+            # For minimal mode, just show major.minor (e.g., "v2.0" from "v2.0.46")
+            if len(claude_ver_str.split('.')) > 2:
+                claude_ver_str = '.'.join(claude_ver_str.split('.')[:2])
+            parts.append(f"🔅 {claude_ver_str}")
+
+        # Add MoAI version if display enabled
         if self._display_config.version:
-            parts.append(f"🗿 Ver {self._truncate_version(data.version)}")
+            truncated_ver = self._truncate_version(data.version)
+            # Add 'v' prefix if not already present
+            version_str = truncated_ver if truncated_ver.startswith("v") else f"v{truncated_ver}"
+            parts.append(f"🗿 {version_str}")
 
         result = self._format_config.separator.join(parts)
 
@@ -284,7 +343,7 @@ class StatuslineRenderer:
         return result
 
     @staticmethod
-    def _truncate_branch(branch: str, max_length: int = 20) -> str:
+    def _truncate_branch(branch: str, max_length: int = 30) -> str:
         """
         Truncate branch name intelligently, preserving SPEC ID if present
 
