@@ -1,4 +1,3 @@
-# type: ignore
 """
 Enhanced Version reader for MoAI-ADK from config.json with performance optimizations
 
@@ -74,10 +73,10 @@ class VersionConfig:
     # Order: 1) MoAI package version, 2) Project version, 3) Fallbacks
     version_fields: List[str] = field(
         default_factory=lambda: [
-            "moai.version",          # ← 1순위: MoAI-ADK 버전
-            "project.version",       # ← 2순위: 프로젝트 버전
-            "version",               # ← 3순위: 일반 버전
-            "project.template_version",  # ← 4순위: 템플릿 버전
+            "moai.version",          # ← 1st priority: MoAI-ADK version
+            "project.version",       # ← 2nd priority: Project version
+            "version",               # ← 3rd priority: General version
+            "project.template_version",  # ← 4th priority: Template version
             "template_version",
         ]
     )
@@ -105,10 +104,10 @@ class VersionReader:
     # Supported version fields in order of priority
     # Order: 1) MoAI package version, 2) Project version, 3) Fallbacks
     DEFAULT_VERSION_FIELDS = [
-        "moai.version",          # ← 1순위: MoAI-ADK 버전
-        "project.version",       # ← 2순위: 프로젝트 버전
-        "version",               # ← 3순위: 일반 버전
-        "project.template_version",  # ← 4순위: 템플릿 버전
+        "moai.version",          # ← 1st priority: MoAI-ADK version
+        "project.version",       # ← 2nd priority: Project version
+        "version",               # ← 3rd priority: General version
+        "project.template_version",  # ← 4th priority: Template version
         "template_version",
     ]
 
@@ -584,7 +583,7 @@ class VersionReader:
             Version string or empty string if package not found
         """
         try:
-            from importlib.metadata import version, PackageNotFoundError
+            from importlib.metadata import PackageNotFoundError, version
 
             try:
                 pkg_version = version("moai-adk")
@@ -624,6 +623,19 @@ class VersionReader:
         """Clear version cache (backwards compatibility)"""
         self._version_cache = None
         self._cache_time = None
+        # Also clear the main cache dictionary
+        self._cache.clear()
+        # Reset cache statistics
+        self._cache_stats = {
+            "hits": 0,
+            "misses": 0,
+            "errors": 0,
+            "cache_hits_by_source": {
+                VersionSource.CONFIG_FILE.value: 0,
+                VersionSource.CACHE.value: 0,
+                VersionSource.FALLBACK.value: 0,
+            },
+        }
         logger.debug("Version cache cleared")
 
     def get_cache_stats(self) -> Dict[str, int]:
@@ -653,7 +665,12 @@ class VersionReader:
         Returns:
             True if cache is expired
         """
-        return not self._is_cache_valid()
+        # Check if cache entry exists and is still valid
+        config_key = str(self._config_path)
+        if config_key not in self._cache:
+            return True
+        entry = self._cache[config_key]
+        return not self._is_cache_entry_valid(entry)
 
     def get_config(self) -> VersionConfig:
         """Get current configuration"""
